@@ -86,18 +86,24 @@ func (n *CandidateNode) CreateChildInArray(index int, node *yaml.Node) *Candidat
 
 func (n *CandidateNode) CreateReplacement(node *yaml.Node) *CandidateNode {
 	return &CandidateNode{
-		Node:           node,
-		Path:           n.createChildPath(nil),
-		LeadingContent: n.LeadingContent,
-		Parent:         n.Parent,
-		Key:            n.Key,
-		IsMapKey:       n.IsMapKey,
-		Document:       n.Document,
-		Filename:       n.Filename,
-		FileIndex:      n.FileIndex,
+		Node:      node,
+		Path:      n.createChildPath(nil),
+		Parent:    n.Parent,
+		Key:       n.Key,
+		IsMapKey:  n.IsMapKey,
+		Document:  n.Document,
+		Filename:  n.Filename,
+		FileIndex: n.FileIndex,
 	}
 }
 
+func (n *CandidateNode) CreateReplacementWithDocWrappers(node *yaml.Node) *CandidateNode {
+	replacement := n.CreateReplacement(node)
+	replacement.LeadingContent = n.LeadingContent
+	replacement.TrailingContent = n.TrailingContent
+	return replacement
+}
+
 func (n *CandidateNode) createChildPath(path interface{}) []interface{} {
 	if path == nil {
 		newPath := make([]interface{}, len(n.Path))
